@@ -320,8 +320,8 @@ def read_hitran(filePath,moleculeName,isotopologue:list=[1],lowerLam:int=1,highe
     mol_MIR = mol_MIR.sort_values(sort_label)
     return mol_MIR
 
-def getLevelFormat(molecule:str,dataFormat:int=2020,level:str='global'):
-    fmt = _fetchLevelFormat(molecule,format=dataFormat)
+def getLevelFormat(molecule:str,format:int=2020,level:str='global'):
+    fmt = _fetchLevelFormat(molecule,format=format)
     if level=='global':
         j=0
     else:
